@@ -1,8 +1,7 @@
 #ifndef KDUN_H
 #define KDUN_H
+#include <qscrollview.h>
 #include <qpopupmenu.h>
-#include <qwidget.h>
-#include "krogueqh.h"
 
 #define PIXMAP_X 9
 #define PIXMAP_Y 20
@@ -28,18 +27,20 @@ public:
   virtual void storeItemPix(int num, const QString &fn);
   virtual void saveProperties(KConfig *);
   virtual void readProperties(KConfig *);
+  virtual void paintPixmap(const QRect &r);
+  virtual bool customWhatsThis() const;
   QPixmap *itempix[10];
 protected:
   QPixmap *pixmap, *dung;
   int whatx, whaty;
   int killoth;
   QPopupMenu whatsthis;
-  KQuickHelpWindow qhwnd;
   void focusObject(int x, int y);
   void paintEvent(QPaintEvent *);
   void keyPressEvent(QKeyEvent *);
   void mousePressEvent(QMouseEvent *);
-  void resizeEvent(QResizeEvent *);
+  void focusInEvent(QFocusEvent *);
+  void focusOutEvent(QFocusEvent *);
 public slots:
   void charfile();
   void highscores();
@@ -52,7 +53,23 @@ public slots:
   void whats();
   void qhHyperlink(QString s);
   void qhClose();
-  void qhAt(KQHWnd *wnd, int x, int y);
+};
+
+#define DCOLS 80
+#define DROWS 24
+
+class KDunView:public QScrollView
+{
+  Q_OBJECT
+public:
+  KDunView(QWidget *p);
+  void setSize(int x=DCOLS*PIXMAP_X, int y=DROWS*PIXMAP_Y);
+  void writeCfg(KConfig *cfg);
+  QSize sizeHint() const {return size();}
+public slots:
+  void makeCellVisible(int row, int col);
+protected:
+  virtual void resizeEvent(QResizeEvent *);
 };
 
 extern KDun *dun;
