@@ -21,9 +21,12 @@ public:
   int rogueArmorClass();
   int rogueExp();
   long rogueExpPoints();
-  const char *rogueName();
-  const char *rogueNick();
-  void setRogueNick(const char *);
+  QString rogueName();
+  const char *rogueNameUtf8();
+  QString rogueNick();
+  const char *rogueNickUtf8();
+  void setRogueNick(const QString &);
+  void setRogueNickUtf8(const char *);
   const char *hungerStr();
   bool warnOnSearch();
   void setWarnOnSearch(bool b);
