@@ -10,7 +10,7 @@ class KMoreButton:public QPushButton
 {
   Q_OBJECT
 public:
-  KMoreButton(const char *text, QWidget *parent=0, const char *name=0);
+  KMoreButton(const QString &text, QWidget *parent=0, const char *name=0);
   void keyPressEvent(QKeyEvent *);
 };
 
@@ -19,18 +19,18 @@ class KMsgBar:public KToolBar
   Q_OBJECT
 public:
   KMsgBar(QWidget *parent=NULL, char *name=NULL);
-  void message(const char *c);
-  void setMessage(const char *msg);
+  void message(const QString &s);
+  void setMessage(const QString &s);
   void removeMore(void);
   void invMsg();
   bool more();
   void saveProperties(KConfig *);
   void readProperties(KConfig *);
-  const char *getMessage(int i=0);
+  QString getMessage(int i=0);
   int msgCount();
-  QFont *normal, *bold;
   int willQuit;
 protected:
+  QFont *normal, *bold;
   QComboBox *combo;
   KMoreButton *p;
   int pbid, fmore, loop;
@@ -43,4 +43,4 @@ signals:
 };
 
 extern KMsgBar *msg;
-#endif
\ No newline at end of file
+#endif
