@@ -1,12 +1,20 @@
+#include <kcmdlineargs.h>
+#include <kmessagebox.h>
 #include <kiconloader.h>
-#include <kfiledialog.h>
-#include <ktopwidget.h>
+#include <qwhatsthis.h>
+#include <kaboutdata.h>
+#include <sys/param.h>
+#include <ktoolbar.h>
+#include <kmenubar.h>
 #include <qkeycode.h>
 #include <ktoolbar.h>
-#include <kmsgbox.h>
+#include <kimageio.h>
+#include <klocale.h>
+#include <kconfig.h>
 #include <unistd.h>
+#include <stdio.h>
 #include <kapp.h>
-#include <kfm.h>
+#include <krun.h>
 #include "rogue/dun.h"
 #include "khtmldlg.h"
 #include "krogueqh.h"
@@ -30,10 +38,14 @@ KDun *dun;
 
 int saved_uid, true_uid;
 
+#define KDE_HOMEPAGE    "http://www.kde.org"
+#define KROGUE_HOMEPAGE "http://ksi.ii.uj.edu.pl/krogue"
+#define BUGS_EMAIL      "M.Zalewski@pegaz.if.uj.edu.pl"
+
 #define FAILED {initFailed=true; return;}
 
 KRogueWnd::KRogueWnd(void)
-:KTopLevelWidget(NULL)
+:KTMainWindow(NULL)
 {
   int i;
   top=this;
@@ -41,12 +53,14 @@ KRogueWnd::KRogueWnd(void)
   for (i=0; i<20; i++) enab[i]=1;
   if (!(cmdr=new KCmdr())) FAILED;
   if (!(gam=new KGame(this))) FAILED;
-  if (!(dun=new KDun(this))) FAILED;
-  setView(dun, true);
+  if (!(dunv=new KDunView(this))) FAILED;
+  if (!(dun=new KDun(dunv->viewport()))) FAILED;
+  setView(dunv, true);
   initMenuBar();
   initToolBar();
   initMsgBar();
   initStatusBar();
+  dunv->addChild(dun);
   connect(cmdr, SIGNAL(noArmor()), SLOT(wearbt()));
   connect(cmdr, SIGNAL(wearsArmor()), SLOT(takeoffbt()));
   connect(cmdr, SIGNAL(noLRing()), SLOT(lputbt()));
@@ -60,19 +74,25 @@ KRogueWnd::KRogueWnd(void)
   connect(cmdr, SIGNAL(enableButtons(bool)), SLOT(enableButtons(bool)));
   connect(cmdr, SIGNAL(wizard()), SLOT(wizard()));
   connect(cmdr, SIGNAL(quit()), dun, SLOT(quit()));
-  connect(cmdr, SIGNAL(help()), SLOT(help()));
+  connect(cmdr, SIGNAL(roguePosChanged(int, int)), dunv, SLOT(makeCellVisible(int, int)));
+  connect(cmdr, SIGNAL(help()), SLOT(appHelpActivated()));
+  connect(kapp, SIGNAL(aboutToQuit()), SLOT(writeCfg()));
   connect(gam, SIGNAL(newNick()), SLOT(newTitle()));
 }
 
 void KRogueWnd::initGame()
 {
-  char fn[250]="";
+  char fn[PATH_MAX]="";
   if (initFailed) return;
   if (!dun->initDungeon(NULL)) FAILED;
   if (kapp->argc()>=2)
   {
-    strncpy(fn, kapp->argv()[1], 250);
-    if (!dun->restoreFile(fn)) FAILED;
+    qstrncpy(fn, kapp->argv()[1], PATH_MAX);
+    if (!dun->restoreFile(fn))
+    {
+      exit(0);
+      return;
+    }
   }
   dun->setFocus();
   if (fn[0]) restoresg=1; else restoresg=0;
@@ -117,25 +137,25 @@ void KRogueWnd::initMenuBar()
   submenu->insertSeparator();
   submenu->insertItem(i18n("&Fast moving\tCtrl"), cmdr, SLOT(run()), 0, 10);
   submenu->insertSeparator();
+  submenu->insertItem(i18n("&Normal window size"), this, SLOT(normalSize()));
+  submenu->insertSeparator();
   submenu->insertItem(i18n("&Options..."), this, SLOT(options()), Key_F9);
   mb->insertItem(i18n("&Commands"), submenu, 4);
-  char buf[400];
-  snprintf(buf, 400, i18n("KRogue %s - rogue for KDE\n\n"
+  submenu=helpMenu(i18n("KRogue %0 - rogue for KDE\n\n"
     "Based on rogue-clone: Version II that can be found at\n"
     "ftp://metalab.unc.edu/pub/Linux/games/dungeon/rogue985.tar.Z\n\n"
-    "Ported to KDE by Mikolaj Zalewski <M.Zalewski@pegaz.if.uj.edu.pl>"),
-    KR_VERSION);
-  submenu=kapp->getHelpMenu(false, buf);
-  submenu->changeItem(Icon("mini/kdehelp.xpm"), submenu->text(0), 0);
-  submenu->changeItem(Icon("about.xpm"), submenu->text(2), 2);
-  submenu->changeItem(Icon("about.xpm"), submenu->text(3), 3);
-  submenu->insertItem(Icon("mini/www.xpm"), i18n("KRogue home page..."), 
-    this, SLOT(krHomepage()), 0, -1, 2);
-  submenu->insertSeparator(4);
-  submenu->insertItem(Icon("mini/www.xpm"), i18n("KDE home page..."), 
-    this, SLOT(kdeHomepage()), 0, -1, 5);
+    "Ported to KDE by Mikolaj Zalewski <M.Zalewski@pegaz.if.uj.edu.pl>").
+    arg(KR_VERSION));
+#define APPICON(x) SmallIcon(x)
+  submenu->insertItem(APPICON("www"), i18n("KRogue home page..."),
+    this, SLOT(krHomepage()), 0, 101, 5);
+  submenu->insertSeparator(7);
+  submenu->insertItem(APPICON("www"), i18n("KDE home page..."),
+    this, SLOT(kdeHomepage()), 0, 102, 8);
+#undef APPICON
   mb->insertItem(i18n("&Help"), submenu);
   setMenu(mb);
+  connect(mb, SIGNAL(highlighted(int)), SLOT(statusHint(int)));
 }
 
 void KRogueWnd::initToolBar()
@@ -163,40 +183,42 @@ void KRogueWnd::initToolBar()
   connect(wear, SIGNAL(activated(int)), cmdr, SLOT(wear(int)));
   connect(lrings, SIGNAL(activated(int)), cmdr, SLOT(putonl(int)));
   connect(rrings, SIGNAL(activated(int)), cmdr, SLOT(putonr(int)));
-  tl->insertButton(Icon("fileopen.xpm"), 2, SIGNAL(clicked()),
+  tl->insertButton(BarIcon("fileopen"), 2, SIGNAL(clicked()),
       dun, SLOT(load()), true, i18n("Restore"));
-  tl->insertButton(Icon("filefloppy.xpm"), 3, SIGNAL(clicked()),
+  tl->insertButton(BarIcon("filesave"), 3, SIGNAL(clicked()),
       gam, SLOT(save()), true, i18n("Save"));
   tl->insertSeparator();
-  tl->insertButton(Icon("invent.xpm"), 18, SIGNAL(clicked()),
+  tl->insertButton(BarIcon("invent"), 18, SIGNAL(clicked()),
       cmdr, SLOT(showinv()), true, i18n("Inventory"));
-  tl->insertButton(Icon("eat.xpm"), 4, eat, true, i18n("Eat"));
-  tl->insertButton(Icon("quaff.xpm"), 5, quaff, true, i18n("Quaff"));
-  tl->insertButton(Icon("read.xpm"), 6, read, true, i18n("Read"));
-  tl->insertButton(Icon("zap.xpm"), 7, zap, true, i18n("Zap"));
-  tl->insertButton(Icon("wield.xpm"), 8, wield, true, i18n("Wield"));
-  tl->insertButton(Icon("throw.xpm"), 9, throwbt, true, i18n("Throw"));
-  tl->insertButton(Icon("drop.xpm"), 10, drop, true, i18n("Drop"));
+  tl->insertButton(BarIcon("eat"), 4, eat, true, i18n("Eat"));
+  tl->insertButton(BarIcon("quaff"), 5, quaff, true, i18n("Quaff"));
+  tl->insertButton(BarIcon("read"), 6, read, true, i18n("Read"));
+  tl->insertButton(BarIcon("zap"), 7, zap, true, i18n("Zap"));
+  tl->insertButton(BarIcon("wield"), 8, wield, true, i18n("Wield"));
+  tl->insertButton(BarIcon("throw"), 9, throwbt, true, i18n("Throw"));
+  tl->insertButton(BarIcon("drop"), 10, drop, true, i18n("Drop"));
   tl->insertSeparator();
-  tl->insertButton(Icon("takeoff.xpm"), 11, SIGNAL(clicked()), cmdr,
+  tl->insertButton(BarIcon("takeoff"), 11, SIGNAL(clicked()), cmdr,
       SLOT(takeoff()), true, i18n("Take off"));
-  tl->insertButton(Icon("lputr.xpm"), 12, lrings, true, i18n("Put on ring"));
-  tl->insertButton(Icon("rputr.xpm"), 13, rrings, true, i18n("Put on ring"));
+  tl->insertButton(BarIcon("lputr"), 12, lrings, true, i18n("Put on ring"));
+  tl->insertButton(BarIcon("rputr"), 13, rrings, true, i18n("Put on ring"));
   tl->insertSeparator();
-  tl->insertButton(Icon("downstair.xpm"), 14, SIGNAL(clicked()), cmdr, 
+  tl->insertButton(BarIcon("downstair"), 14, SIGNAL(clicked()), cmdr,
       SLOT(downstair()), true, i18n("Downstair"));
-  tl->insertButton(Icon("upstair.xpm"), 15, SIGNAL(clicked()), cmdr,
+  tl->insertButton(BarIcon("upstair"), 15, SIGNAL(clicked()), cmdr,
       SLOT(upstair()), true, i18n("Upstair"));
-  tl->insertButton(Icon("rest.xpm"), 16, SIGNAL(clicked()), cmdr,
+  tl->insertButton(BarIcon("rest"), 16, SIGNAL(clicked()), cmdr,
       SLOT(restbt()), true, i18n("Rest"));
-  tl->insertButton(Icon("search.xpm"), 17, SIGNAL(clicked()), cmdr,
+  tl->insertButton(BarIcon("kr_search"), 17, SIGNAL(clicked()), cmdr,
       SLOT(searchbt()), true, i18n("Search"));
+  tl->insertSeparator();
+  tl->insertButton(BarIcon("contexthelp"), 100, SIGNAL(clicked()), this,
+      SLOT(whatsthis()), true, i18n("What's this?"));
   tl->setAutoRepeat(16, true);
   tl->setAutoRepeat(17, true);
   tlButtons=18;
-  KRQuickHelp::addToolButton(tl);
   addToolBar(tl);
-  krqhSetToolBar(tl);
+  krwtSetToolBar(tl);
 }
 
 void KRogueWnd::initMsgBar(void)
@@ -207,22 +229,20 @@ void KRogueWnd::initMsgBar(void)
 
 void KRogueWnd::initStatusBar(void)
 {
-  if (!(s=new KStatusBar(top, i18n("Level")))) FAILED;
-  s->insertItem(statusStr(1, "MM"), 1);
-  s->insertItem(statusStr(2, "MMMMM"),2);
-  s->insertItem(statusStr(3, "MMM(MMM)"),3);
-  s->insertItem(statusStr(4, "MM(MM)"),4);
-  s->insertItem(statusStr(5, "MM"), 5);
-  s->insertItem(statusStr(6, "MM/MMMMM"), 6);
-  s->insertItem("MMMMMMMM", 7);
+  if (!(s=new KStatusBar(top))) FAILED;
+  s->insertItem(statusStr(1, "MM"), 1, 1);
+  s->insertItem(statusStr(2, "MMMMM"),2, 1);
+  s->insertItem(statusStr(3, "MMM(MMM)"),3, 1);
+  s->insertItem(statusStr(4, "MM(MM)"),4, 1);
+  s->insertItem(statusStr(5, "MM"), 5, 1);
+  s->insertItem(statusStr(6, "MM/MMMMM"), 6, 1);
+  s->insertItem("MMMMMMMM", 7, 1);
   setStatusBar(s);
 }
 
-char *KRogueWnd::statusStr(int id, char *str)
+QString KRogueWnd::statusStr(int id, const char *str)
 {
-  static char retstr[200];
-  const char *tstr;
-  int len;
+  QString tstr;
   switch (id)
   {
     case 1: tstr=i18n("Level: "); break;
@@ -233,16 +253,42 @@ char *KRogueWnd::statusStr(int id, char *str)
     case 6: tstr=i18n("Exp: "); break;
     default: tstr="???";
   }
-  strncpy(retstr, tstr, 199);
-  len=strlen(retstr);
-  strncat(retstr, str, 199-len);
-  return retstr;
+  tstr+=str;
+  return tstr;
+}
+
+void KRogueWnd::statusHint(int i)
+{
+  static int hint=0;
+  int newhint=1;
+
+  switch (i)
+  {
+    case 101:
+      s->message(i18n("Visit ")+KROGUE_HOMEPAGE);
+      break;
+    case 102:
+      s->message(i18n("Visit ")+KDE_HOMEPAGE);
+      break;
+    default:
+      newhint=0;
+      if (hint) s->clear();
+  }
+
+  hint=newhint;
 }
 
 void KRogueWnd::show()
 {
   int x, y;
-  KTopLevelWidget::show();
+
+  cfg->setGroup("Window");
+  dunv->setSize(cfg->readNumEntry("W", DCOLS*PIXMAP_X),
+                cfg->readNumEntry("H", DROWS*PIXMAP_Y));
+  resize(sizeHint());
+  dunv->makeCellVisible(rogue.row, rogue.col);
+
+  KTMainWindow::show();
   if (!kapp->isRestored())
   {
     cfg->setGroup("Window");
@@ -251,11 +297,11 @@ void KRogueWnd::show()
     if (x!=-1 && y!=-1) move(x, y);
     readToolBar(tl, "Toolbar");
     readToolBar(msg, "Msgbar");
-    readMenuBar(mb, "Menu");
   }
+
   if (!restoresg)
   {
-    KHTMLDlg intro(QSize(600, 400), top);
+    KHTMLDlg intro(QSize(600, 330), top);
     intro.setVar("DUNGEONS_OF_DOOM", i18n("The Dungeons of Doom"));
     intro.setVar("PAR0", i18n(
       "You have just finished your years as a student at the local fighter's\n"
@@ -277,11 +323,16 @@ void KRogueWnd::show()
       "Doom. It is late at night, so you make camp at the entrance and spend the night\n"
       "sleeping under the open skies. In the morning you gather your weapons, put on\n"
       "your armor, eat what is almost your last food, and enter the dungeons.\n"));
-    intro.loadFile("intro.html");
+    intro.loadFile("intro.qml");
     if (intro.loaded()) intro.exec();
   }
 }
 
+void KRogueWnd::whatsthis()
+{
+  QWhatsThis::enterWhatsThisMode();
+}
+
 void KRogueWnd::options()
 {
   KROpts optdlg(this);
@@ -290,53 +341,44 @@ void KRogueWnd::options()
 
 void KRogueWnd::wizard()
 {
-  const char *c;
+  QString str;
   if (::wizard) wizardize(NULL);
     else
     {
       KStrDlg strdlg(i18n("&Wizard's password:"), true, top);
       strdlg.exec();
-      c=strdlg.text();
-      if (strdlg.result()!=QDialog::Rejected && c!=NULL && c[0])
-        wizardize(c);
+      str=strdlg.text();
+      if (strdlg.result()!=QDialog::Rejected && !str.isNull() && !str.isEmpty())
+        wizardize(str.utf8());
     }
   if (::wizard) top->mb->setAccel(0, 2);
     else top->mb->setAccel(CTRL+Key_S, 2);
 }
 
-void KRogueWnd::help()
-{
-  kapp->invokeHTMLHelp("krogue/index.html", NULL);
-}
-
 void KRogueWnd::kdeHomepage()
 {
-  KFM kfm;
-  kfm.openURL("http://www.kde.org");
+  new KRun(KDE_HOMEPAGE);
 }
 
 void KRogueWnd::krHomepage()
 {
-  KFM kfm;
-  kfm.openURL("http://ksi.ii.uj.edu.pl/krogue");
+  new KRun(KROGUE_HOMEPAGE);
 }
 
 void KRogueWnd::writeCfg()
 {
   cfg->setGroup("Window");
-  cfg->writeEntry("X", top->x());
-  cfg->writeEntry("Y", top->y());
-  writeMenuBar(mb, "Menu");
+  cfg->writeEntry("X", geometry().x());
+  cfg->writeEntry("Y", geometry().y());
+  dunv->writeCfg(cfg);
   writeToolBar(tl, "Toolbar");
   writeToolBar(msg, "Msgbar");
 }
 
-void KRogueWnd::writeMenuBar(KMenuBar *mb, const char *name)
+void KRogueWnd::closeEvent(QCloseEvent *e)
 {
-  char str[200];
-  snprintf(str, 200, "%d,%d,%d", (int)(mb->menuBarPos()),
-    mb->x(), mb->y());
-  cfg->writeEntry(name, str);
+  KTMainWindow::closeEvent(e);
+  if (e->isAccepted()) writeCfg();
 }
 
 void KRogueWnd::writeToolBar(KToolBar *tl, const char *name)
@@ -347,26 +389,12 @@ void KRogueWnd::writeToolBar(KToolBar *tl, const char *name)
   cfg->writeEntry(name, str);
 }
 
-void KRogueWnd::readMenuBar(KMenuBar *mb, const char *name)
-{
-  KMenuBar::menuPosition p;
-  int x, y;
-  QString str=cfg->readEntry(name, "0,0,0");
-  sscanf((const char *)str, "%d,%d,%d", (int *)&p, &x, &y);  
-  mb->setMenuBarPos(p);
-  if (p==KMenuBar::Floating)
-  {
-    mb->move(x, y);
-    mb->show();
-  }
-}
-
 void KRogueWnd::readToolBar(KToolBar *tl, const char *name)
 {
   KToolBar::BarPosition p;
   int x, y;
   QString str=cfg->readEntry(name, "0,0,0");
-  sscanf((const char *)str, "%d,%d,%d", (int *)&p, &x, &y);
+  sscanf(str.latin1(), "%d,%d,%d", (int *)&p, &x, &y);
   tl->setBarPos(p);
   if (p==KToolBar::Floating)
   {
@@ -385,11 +413,16 @@ void KRogueWnd::enableButtons(bool enabled)
     if (enab[i]) mb->setItemEnabled(i, enabled);
 }
 
-void KRogueWnd::closeEvent(QCloseEvent *e)
+bool KRogueWnd::queryClose()
 {
   if (!msg->willQuit) dun->quit(false);
-  if (msg->willQuit) e->accept();
-    else e->ignore();
+  return msg->willQuit;
+}
+
+void KRogueWnd::normalSize()
+{
+  dunv->setSize();
+  resize(sizeHint());
 }
 
 void KRogueWnd::printStats(int t)
@@ -403,7 +436,7 @@ void KRogueWnd::printStats(int t)
   }
   if (t&STAT_GOLD)
   {
-    snprintf(str, 20, "%d", gam->rogueGold());
+    snprintf(str, 20, "%ld", gam->rogueGold());
     s->changeItem(statusStr(2, str), 2);
   }
   if (t&STAT_HP)
@@ -428,7 +461,8 @@ void KRogueWnd::printStats(int t)
     s->changeItem(statusStr(6, str), 6);
   }
   if (t&STAT_HUNGER)
-    if (gam->hungerStr()) s->changeItem(loc->translate(gam->hungerStr()), 7);
+    if (gam->hungerStr())
+      s->changeItem(i18n(gam->hungerStr()), 7);
       else s->changeItem("", 7);
 }
 
@@ -436,64 +470,64 @@ void KRogueWnd::newTitle()
 {
   char title[MSGLEN];
   short level=gam->level();
-  format_str(title, "Rogue - ${1} on level ${0}", "caption", 2, SNUMBER, 0, &level,
-    STRING, 0, gam->rogueName());
-  setCaption(title);
+  format_str(title, "${1} on level ${0} - Rogue", "caption", 2, SNUMBER, 0, &level,
+    STRING, 0, gam->rogueNameUtf8());
+  setPlainCaption(QString::fromUtf8(title));
 }
 
 void KRogueWnd::takeoffbt()
 {
-  krqhRemoveTl(tl, 11);
+  krwtRemoveTl(tl, 11);
   tl->removeItem(11);
-  tl->insertButton(Icon("takeoff.xpm"), 11, SIGNAL(clicked()), cmdr,
+  tl->insertButton(BarIcon("takeoff"), 11, SIGNAL(clicked()), cmdr,
      SLOT(takeoff()), true, i18n("Take off"), 12);
-  krqhSetTlTakeOff(tl);
+  krwtSetTlTakeOff(tl);
 }
 
 void KRogueWnd::wearbt()
 {
-  krqhRemoveTl(tl, 11);
+  krwtRemoveTl(tl, 11);
   tl->removeItem(11);
-  tl->insertButton(Icon("wear.xpm"), 11, wear, true, i18n("Wear"), 12);
-  krqhSetTlWear(tl);
+  tl->insertButton(BarIcon("wear"), 11, wear, true, i18n("Wear"), 12);
+  krwtSetTlWear(tl);
 }
 
 void KRogueWnd::lputbt()
 {
-  krqhRemoveTl(tl, 12);
+  krwtRemoveTl(tl, 12);
   tl->removeItem(12);
-  tl->insertButton(Icon("lputr.xpm"), 12, lrings, true, i18n("Put on ring"), 13);
-  krqhSetTlLPutOn(tl);
+  tl->insertButton(BarIcon("lputr"), 12, lrings, true, i18n("Put on ring"), 13);
+  krwtSetTlLPutOn(tl);
 }
 
 void KRogueWnd::rputbt()
 {
-  krqhRemoveTl(tl, 13);
+  krwtRemoveTl(tl, 13);
   tl->removeItem(13);
-  tl->insertButton(Icon("rputr.xpm"), 13, rrings, true, i18n("Put on ring"), 14);
-  krqhSetTlRPutOn(tl);
+  tl->insertButton(BarIcon("rputr"), 13, rrings, true, i18n("Put on ring"), 14);
+  krwtSetTlRPutOn(tl);
 }
 
 void KRogueWnd::lrembt(struct obj *obj)
 {
   char name[MSGLEN];
   get_desc(obj, name);
-  krqhRemoveTl(tl, 12);
+  krwtRemoveTl(tl, 12);
   tl->removeItem(12);
-  tl->insertButton(Icon("lremr.xpm"), 12, SIGNAL(clicked()), cmdr, 
-    SLOT(lremr()), true, name, 13);
-  krqhSetTlLRemove(tl);
+  tl->insertButton(BarIcon("lremr"), 12, SIGNAL(clicked()), cmdr,
+    SLOT(lremr()), true, QString::fromUtf8(name), 13);
+  krwtSetTlLRemove(tl);
 }
 
 void KRogueWnd::rrembt(struct obj *obj)
 {
   char name[MSGLEN];
   get_desc(obj, name);
-  krqhRemoveTl(tl, 13);
+  krwtRemoveTl(tl, 13);
   tl->removeItem(13);
-  tl->insertButton(Icon("rremr.xpm"), 13, SIGNAL(clicked()), cmdr, 
-    SLOT(rremr()), true, name, 14);
-  krqhSetTlRRemove(tl);
+  tl->insertButton(BarIcon("rremr"), 13, SIGNAL(clicked()), cmdr,
+    SLOT(rremr()), true, QString::fromUtf8(name), 14);
+  krwtSetTlRRemove(tl);
 }
 
 void KRogueWnd::stairbt(bool e)
@@ -509,7 +543,7 @@ void KRogueWnd::setRunning(bool e)
 
 void KRogueWnd::saveProperties(KConfig *cfg)
 {
-  KTopLevelWidget::saveProperties(cfg);
+  KTMainWindow::saveProperties(cfg);
   dun->saveProperties(cfg);
   msg->saveProperties(cfg);
   cmdr->saveProperties(cfg);
@@ -517,7 +551,7 @@ void KRogueWnd::saveProperties(KConfig *cfg)
 
 void KRogueWnd::readProperties(KConfig *cfg)
 {
-  KTopLevelWidget::readProperties(cfg);
+  KTMainWindow::readProperties(cfg);
   msg->readProperties(cfg);
   dun->readProperties(cfg);
   cmdr->readProperties(cfg);
@@ -537,25 +571,29 @@ int main(int argc, char **argv)
   saved_uid=geteuid();
   setuid(true_uid=getuid());
 
-  KApplication a(argc, argv, "krogue");
-  loc=a.getLocale(); 
-  cfg=a.getConfig();
+  KAboutData about("krogue", I18N_NOOP("KRogue"), KR_VERSION,
+      I18N_NOOP("Rogue for KDE"), 0, NULL, KROGUE_HOMEPAGE,
+      I18N_NOOP("Rogue for KDE"), BUGS_EMAIL);
+  KCmdLineArgs::init(argc, argv, &about);
+  KApplication a(argc, argv);
+  KImageIO::registerFormats();
+  loc=KGlobal::locale();
+  cfg=KGlobal::config();
   top=new KRogueWnd;
   if (a.isRestored()) top->restore(1);
     else top->initGame();
   if (!top || top->initFailed)
   {
-    KMsgBox::message(NULL, i18n("Rogue"), i18n("Couldn't start KRogue"));
+    KMessageBox::sorry(NULL, i18n("Couldn't start KRogue"), i18n("Rogue"));
     return 1;
   }
   if (top->restoresg==-1) return 0;
-  top->show();
+  if (!a.isRestored()) top->show();
   a.setMainWidget(top);
-  krqhSetStatusBar(top->s);
+  krwtSetStatusBar(top->s);
   cfg->setGroup("Settings");
   ret=a.exec();
-  top->writeCfg();
   cfg->setGroup("Settings");
   cmdr->writeCfg(cfg);
   return ret;
-}
\ No newline at end of file
+}
