@@ -1,31 +1,42 @@
-#include <kquickhelp.h>
-#include <kapp.h>
+#include <qwhatsthis.h>
+#include <klocale.h>
+#include <stdio.h>
 #include "kropts.h"
 
-void KROpts::setQuickHelp()
+void KROpts::setWhatsThis()
 {
-  const char *n=i18n(
+  QString n=i18n(
       "By default your login name is used to\n"
       "call you. If you want to use another name,\n"
       "check this box and enter the nickname.");
-  KQuickHelp::add(nickch, n);
-  KQuickHelp::add(nicked, n);
-  KQuickHelp::add(sleepch, i18n(
+  QWhatsThis::add(nickch, n);
+  QWhatsThis::add(nicked, n);
+  QWhatsThis::add(sleepch, i18n(
       "When you are resting a monster may come\n"
       "to you and hit you several times before\n"
       "you notice him and stop resting. If you\n"
       "check this box a warning will be displayed\n"
       "in such situations, the More button will\n"
       "appear and the game will pause."));
-  KQuickHelp::add(searchch, i18n(
+  QWhatsThis::add(searchch, i18n(
       "When you are searching a monster may come\n"
       "to you and hit you several times before\n"
       "you notice him and stop searching. If you\n"
       "check this box a warning will be displayed\n"
       "in such situations, the More button will\n"
       "appear and the game will pause."));
-  KQuickHelp::add(Okbt, i18n(
+  QWhatsThis::add(Okbt, i18n(
       "Accept the changes and close the dialog"));
-  KQuickHelp::add(Cancelbt, i18n(
+  QWhatsThis::add(Cancelbt, i18n(
       "Reject the changes and close the dialog"));
-}
\ No newline at end of file
+}
+
+void  KROpts::removeWhatsThis()
+{
+  QWhatsThis::remove(nickch);
+  QWhatsThis::remove(nicked);
+  QWhatsThis::remove(sleepch);
+  QWhatsThis::remove(searchch);
+  QWhatsThis::remove(Okbt);
+  QWhatsThis::remove(Cancelbt);
+}
